package api

import (
	"net/http/httptest"
	"testing"

	"github.com/ovh/cds/engine/api/pipeline"
	"github.com/ovh/cds/engine/api/test"
	"github.com/ovh/cds/engine/api/test/assets"
	"github.com/ovh/cds/sdk"
	"github.com/stretchr/testify/assert"
)

func Test_getPipelineExportHandler(t *testing.T) {
	api, db, _, end := newTestAPI(t)
	defer end()

	u, pass := assets.InsertAdminUser(t, db)
	proj := assets.InsertTestProject(t, db, api.Cache, sdk.RandomString(10), sdk.RandomString(10))
	test.NotNil(t, proj)
	pipName := sdk.RandomString(10)
	pip := &sdk.Pipeline{
		ProjectID: proj.ID,
		Name:      pipName,
	}

	if err := pipeline.InsertPipeline(db, api.Cache, proj, pip); err != nil {
		t.Fatal(err)
	}

	//Prepare request
	vars := map[string]string{
		"permProjectKey": proj.Key,
		"pipelineKey":    pip.Name,
	}
	uri := api.Router.GetRoute("GET", api.getPipelineExportHandler, vars)
	test.NotEmpty(t, uri)
	req := assets.NewAuthentifiedRequest(t, u, pass, "GET", uri, nil)

	//Do the request
	rec := httptest.NewRecorder()
	api.Router.Mux.ServeHTTP(rec, req)
	assert.Equal(t, 200, rec.Code)

	//Check result
	t.Logf(">>%s", rec.Body.String())

}
